<template>
    <div class="report-overview fullpage">
        <div class="btn-container">
            <div class="btn-group">
                <div class="level-wrapper">
                    <span @click="changeLevelShow('showLevelA')" :class="[
                        'level',
                        'levelA',
                        {
                            active: showLevelA,
                        },
                    ]">A
                    </span>
                </div>
                <div class="level-wrapper">
                    <span @click="changeLevelShow('showLevelB')" :class="[
                        'level',
                        'levelB',
                        {
                            active: showLevelB,
                        },
                    ]">B
                    </span>
                </div>
                <div class="level-wrapper">
                    <span @click="changeLevelShow('showLevelC')" :class="[
                        'level',
                        'levelC',
                        {
                            active: showLevelC,
                        },
                    ]">C
                    </span>
                </div>
                <div class="level-wrapper">
                    <span @click="changeLevelShow('showLevelD')" :class="[
                        'level',
                        'levelD',
                        {
                            active: showLevelD,
                        },
                    ]">D
                    </span>
                </div>
                <div class="level-wrapper">
                    <span @click="changeLevelShow('showLevelE')" :class="[
                        'level',
                        'levelE',
                        {
                            active: showLevelE,
                        },
                    ]">E
                    </span>
                </div>
                <el-tag style="cursor: pointer;font-size: 14px;" effect="dark" @click="changeColor">{{ allcolor ? '取消赋色' :
                    '全档赋色' }}</el-tag>
            </div>
            <div class="btn-right">
                <el-button class="download" type="primary" @click="tableChange(false)" size="mini">本期晾晒指标</el-button>
                <el-button class="download" type="primary" @click="tableChange(true)" size="mini">全量指标</el-button>
                <el-button class="download" type="primary" size="mini" icon="el-icon-download"
                    @click="download">导出报表</el-button>
            </div>

        </div>
        <div style="width: 100%;height: calc(100% - 48px);white-space: nowrap; /* 防止单元格内容换行 */
  overflow: auto;">
            <el-table height="calc(100% )" v-if="dataReady" align="center" :data="tableData" id="mix-table-bigger-preview"
                class="dialog_table quxian" :cell-style="{ 'text-align': 'center' }" style="min-width: 100%;overflow: auto;"
                :header-cell-style="{ 'text-align': 'center' }" v-loading="loading"
                :element-loading-background="loadingColor">
                <el-table-column prop="unitName" label="区县" min-width="60">
                    <template v-slot="{ row }">
                        <div :style="row.areaType == 1
                            ? 'text-align:left;padding-left:10px;font-weight:bold;font-size:13px;'
                            : 'text-align:center'
                            ">
                            {{ row.unitName }}
                        </div>
                    </template>
                </el-table-column>
                <el-table-column prop="allSn" label="排名" min-width="60" sortable />
                <el-table-column prop="allGrade" label="分档" min-width="50">
                    <template v-slot="{ row }">
                        <span :class="[
                            'level',
                            {
                                levelA: showLevelA && row.allGrade == 'A',
                            },
                            {
                                levelB: showLevelB && row.allGrade == 'B',
                            },
                            {
                                levelC: showLevelC && row.allGrade == 'C',
                            },
                            {
                                levelD: showLevelD && row.allGrade == 'D',
                            },
                            {
                                levelE: showLevelE && row.allGrade == 'E',
                            },
                        ]">
                            {{ row.allGrade }}
                        </span>
                    </template>
                </el-table-column>

                <el-table-column :label="item.label" min-width="120" v-for="item in columnData" :key="item.id">
                    <el-table-column label="分档" min-width="50" v-if="item.id !== 8">
                        <template v-slot="{ row }">
                            <span :class="[
                                'level',showLevelA ? `level${row[item.grade]}` : '',]">
                                {{ row[item.grade] || '-' }}
                            </span>
                        </template>
                    </el-table-column>
                    <el-table-column label="实际值" min-width="90" sortable>
                        <template v-slot="{ row }">
                            {{ !row[item.value]&&!row[item.grade] ? '-' : row[item.value] }}
                        </template>
                    </el-table-column>
                </el-table-column>


            </el-table>
        </div>

    </div>
</template>

<script>
import apiList from '@/api/bigScreen/districView.js'
export default {
    name: 'reportPreview',
    components: {},
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            allcolor: false,
            showLevelA: false,
            showLevelB: false,
            showLevelC: false,
            showLevelD: false,
            showLevelE: false,
            dataReady: true,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            loading: false,
            // 主城都市区编码
            mainCode: [
                '500103000000',
                '500112000000',
                '500108000000',
                '500106000000',
                '500104000000',
                '500107000000',
                '500105000000',
                '500113000000',
                '500109000000',
                '500119000000',
                '500192000000',
                '500117000000',
                '500151000000',
                '500120000000',
                '500118000000',
                '500111000000',
                '500153000000',
                '500115000000',
                '500102000000',
                '500152000000',
                '500116000000',
                '500191000000',
                '500110000000',
                '500113000000',
                '500193000000',
            ],
            // 渝东北三峡库区城镇群
            northeastCode: [
                '500233000000',
                '500236000000',
                '500238000000',
                '500155000000',
                '500237000000',
                '500235000000',
                '500231000000',
                '500154000000',
                '500101000000',
                '500230000000',
                '500229000000',
            ],
            // 渝东南武陵山区城镇群
            southeastCode: [
                '500114000000',
                '500241000000',
                '500156000000',
                '500240000000',
                '500242000000',
                '500243000000',
            ],
            tableData: [],
            rowMergeIndex: [0, 22, 34],
            isAllTable: false,
            columnData: []
        }
    },
    mounted() {
        this.setIndexColumnData()
        this.initData()
        this.$bus.$on('changeDate', () => {
            this.setIndexColumnData()
            this.initData()
        })
    },
    methods: {
        setIndexColumnData() {
            let { quarter, year } = JSON.parse(sessionStorage.getItem('searchDate'))
            let columnData  = [
                {
                    id: 1,
                    label: '建立企业上市\n助推机制进展（分）', 
                    grade: 'listedCompaniesGrade', 
                    value: 'listedCompaniesDivide',
                    quarter: [3]
                },
                {
                    id: 2,
                    label: '打造“信用重庆”\n升级版进展（分）',
                    grade: 'creditGrade', 
                    value: 'creditRate',
                    quarter: [3]
                },
                {
                    id: 3,
                    grade: 'nationalProjectGrade', 
                    value: 'nationalProjectNum',
                    quarter: [2, 3]
                },
                {
                    id: 4,
                    grade: 'workableNationalAddGrade', 
                    value: 'workableNationalAddNum',
                    quarter: [3]
                },
                {
                    id: 5,
                    label: '改革经验获全国性\n肯定评价（次）',
                    grade: 'nationwideGrade', 
                    value: 'nationwideNum',
                    quarter: [2, 3]
                },
                {
                    id: 6,
                    label: '改革经验获\n全市推广（次）',
                    grade: 'cityGrade', 
                    value: 'cityNum',
                    quarter: [2, 3]
                },
                {
                    id: 7,
                    label: '社情民意电话\n调查满意度（分）',
                    grade: 'satisfiedGrade', 
                    value: 'satisfied',
                    quarter: [2, 3]
                },
                {
                    id: 8,
                    label: '数字重庆建设\n进展（%）',
                    value: 'digitRate',
                    quarter: [2, 3]
                },
                {
                    id: 9,
                    label: '国企改革进展\n（分）',
                    grade: '', 
                    value: '',
                    quarter: []
                },
                {
                    id: 10,
                    label: '制造业“亩均论英雄”\n改革进展（分）', 
                    grade: '', 
                    value: '',
                    quarter: []
                },
                {
                    id: 11,
                    label: '承接的国家级试点\n按时通过验收率（%）',
                    grade: 'nationalPassGrade',
                    value: 'nationalPassRate',
                    quarter: []
                }
            ]
            columnData[2].label = quarter == 2 ? '承接国家试点\n项目数（个）' : '正在推进中的国家改革试点\n项目数（个）'
            columnData[3].label = quarter == 2 ? '本年度新增国家试点\n项目数（个）' : '新增国家改革试点\n项目数（个）'
            columnData[7].label = quarter == 3 ? '数字重庆建设\n进展（分）' : '数字重庆建设\n进展（%）'
            let lsColumnData = columnData.filter(item => item.quarter.includes(quarter))
            console.log(lsColumnData);
            this.columnData = this.isAllTable ? columnData : lsColumnData
        },
        tableChange(val) {
            this.isAllTable = val
            this.setIndexColumnData()
        },
        changeColor() {
            this.allcolor = !this.allcolor
            this.showLevelA = this.allcolor
            this.showLevelB = this.allcolor
            this.showLevelC = this.allcolor
            this.showLevelD = this.allcolor
            this.showLevelE = this.allcolor
        },
        changeLevelShow(level) {
            this[level] = !this[level]
        },
        initData() {
            this.loading = true
            let searchDate = sessionStorage.getItem('searchDate')
            searchDate = JSON.parse(searchDate)
            let data = this.qs.stringify({
                year: searchDate.year,
                quarter: searchDate.quarter,
            })
            apiList.statementDetail(data, (res) => {
                const data = res || []
                this.tableData = data
                // 主城都市区编码
                let mainList = this.arrHasSameValue(data, this.mainCode)
                let length1 = mainList.length + 1
                // 渝东北三峡库区城镇群
                let northeastList = this.arrHasSameValue(
                    data,
                    this.northeastCode
                )
                let length2 = northeastList.length + 1 + length1
                // 渝东南武陵山区城镇群
                let southeastList = this.arrHasSameValue(
                    data,
                    this.southeastCode
                )
                // this.tableData = [
                //     {
                //         unitName: '主城都市区',
                //         areaType: 1,
                //     },
                //     ...mainList,
                //     {
                //         unitName: '渝东北三峡库区城镇群',
                //         areaType: 1,
                //     },
                //     ...northeastList,
                //     {
                //         unitName: '渝东南武陵山区城镇群',
                //         areaType: 1,
                //     },
                //     ...southeastList,
                // ]
                this.rowMergeIndex = [0, length1, length2]
                this.loading = false
            })
        },
        // 找出两个数组相同的数据
        arrHasSameValue(arr1, arr2) {
            return arr1.filter((item) => {
                if (arr2.indexOf(item.unitCode) > -1) {
                    return item
                }
            })
        },
        objectSpanMethod({ row, column, rowIndex, columnIndex }) {
            if (this.rowMergeIndex.includes(rowIndex)) {
                if (columnIndex == 0) {
                    return [1, 16]
                } else if (columnIndex !== 0) {
                    return [0, 0]
                }
            }
        },
        download() {
            let searchDate = sessionStorage.getItem('searchDate')
            searchDate = JSON.parse(searchDate)
            let data = this.qs.stringify({
                year: searchDate.year,
                quarter: searchDate.quarter,
            })
            apiList.exportReport(data, this.isAllTable, (res) => {
                console.log(res)
            })
        },
    },
}
</script>

<style lang="scss" scoped>
* {
    font-size: 18PX !important;
}
/deep/.el-table__cell {
    .cell {
        font-size: 18PX !important;
    }
}
.btn-right {
    .download {
        margin-right: 10px;

        /deep/span {
            font-size: 16PX;
        }
    }

    :last-child {
        margin-right: 0;
    }
}

/deep/#mix-table-bigger-preview.dialog_table.el-table th>.cell {
    font-size: 14PX;
    font-family: SimHei;
    font-weight: 400;
    color: #ffffff;
}
</style>

<style lang="scss">
.report-overview.fullpage {
    width: 100%;
    height: 100%;
}

.download.el-button {
    margin: 10px 0;
}

// .report-overview {
//     height: 700px;
// }
#mix-table-bigger-preview .el-table--border th,
.el-table--border td {
    border-right: 1px solid rgb(39, 86, 162) !important;
}

#mix-table-bigger-preview.el-table th.el-table__cell.is-leaf,
#mix-table-bigger-preview.el-table td.el-table__cell {
    border-bottom: 1px solid rgb(39, 86, 162) !important;
}

#mix-table-bigger-preview.el-table th.el-table__cell>.cell {
    white-space: pre;
}

#mix-table-bigger-preview.dialog_table.el-table {
    background-color: rgba(1, 39, 101, 1) !important;
    // tr {
    //     background-color: rgba(1, 39, 101, 1)!important;
    //     color: #FFFFFF!important;
    // }
    // tr:nth-of-type(2n+1){
    //     background-color: rgb(3, 45, 113)!important;
    //     color: #FFFFFF!important;
    // }

    thead tr {
        background: none !important;
    }

    thead tr,
    thead tr th,
    .el-table__empty-block {
        background: none !important;
        background-color: #114385 !important;
        color: #ffffff;
    }

    th>.cell {
        font-size: 16px;
        font-family: SimHei;
        font-weight: 400;
        color: #ffffff;
    }

    td>.cell {
        color: #ffffff !important;
    }

    td.el-table__cell div {
        font-size: 18px;
    }
}

#mix-table-bigger-preview.el-table--border {
    border: 1px solid rgb(39, 86, 162) !important;

    .el-table__cell {
        border-right: 1px solid rgb(39, 86, 162) !important;
    }

    th.el-table__cell {
        border-bottom: 1px solid rgb(39, 86, 162) !important;
    }

    td {
        border-right: 1px solid rgb(39, 86, 162) !important;
    }

    th {
        border-right: 1px solid rgb(39, 86, 162) !important;
    }
}

#mix-table-bigger-preview.el-table {
    tr {
        background-color: rgba(1, 39, 101, 1) !important;
        color: #ffffff !important;
    }
}

#mix-table-bigger-preview.el-table--enable-row-hover .el-table__body tr:hover>td.el-table__cell {
    background-color: rgba(2, 115, 233, 0.3) !important;
}

#mix-table-bigger-preview.el-table.el-table--border tbody tr:hover>td {
    background-color: rgba(2, 115, 233, 0.3) !important;
}

#mix-table-bigger-preview.el-table--group::after,
#mix-table-bigger-preview.el-table--border::after,
#mix-table-bigger-preview.el-table::before {
    background-color: #001f47 !important;
}

#mix-table-bigger-preview {

    /* 设置滚动条的样式 */
    ::-webkit-scrollbar {
        width: 8px !important; //垂直方向上的宽
        height: 8px !important; //水平方向上的宽
    }

    /* 滚动槽 */
    ::-webkit-scrollbar-track {
        border-radius: 0;
        background-color: #01215a !important;
    }

    /* 滚动条滑块 */
    ::-webkit-scrollbar-thumb {
        border-radius: 6px;
        background-color: rgba(#fff, 0.1) !important;
    }

    /*滚动条交叉样式*/
    ::-webkit-scrollbar-corner {
        background: #01215a !important;
    }
}

.level {
    width: 26px;
    height: 26px;
    border-radius: 13px;
    line-height: 26px;
    text-align: center;
    font-size: 18px;
    font-family: SimHei;
    font-weight: 400;
    color: #ffffff;
    display: inline-block;
    transition: all 0.2s;
    transform-origin: 50% 50%;
}

.levelA {
    background-color: #20A367 !important;
    font-weight: bold;
    color: #ffffff !important;
}

.levelB {
    background-color: #3877B2 !important;
    font-weight: bold;
    color: #ffffff !important;
}

.levelC {
    background-color: #E3C428 !important;
    font-weight: bold;
    color: #ffffff !important;
}

.levelD {
    background-color: #E49317 !important;
    font-weight: bold;
    color: #ffffff !important;
}

.levelE {
    background-color: #B04332 !important;
    font-weight: bold;
    color: #ffffff !important;
}

.btn-container {
    display: flex;
    justify-content: space-between;
    align-items: center;
    height: 48PX;
}

.btn-group {
    display: flex;
    justify-content: space-evenly;
    align-items: center;
}

.btn-group .level {
    cursor: pointer;
    color: #666;
    font-weight: normal;
}

.btn-group .level.active {
    width: 30px;
    height: 30px;
    border-radius: 15px;
    line-height: 30px;
    font-weight: bold;
}

.level-wrapper {
    width: 34px;
    height: 34px;
    line-height: 34px;
    margin-right: 20px;
}
</style>
